==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/mots/lang/mots_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/mots/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Groupe important :</b> il est fortement conseillé de sélectionner un mot-clé dans ce groupe.',
	'avis_doublon_mot_cle' => 'Un mot existe deja avec ce titre. Êtes vous sûr de vouloir créer le même ?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'les administrateurs du site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'les rédacteurs',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'les visiteurs du site public lorsqu\'ils postent un message dans un forum.',

	// C
	'creer_et_associer_un_mot' => 'Créer et associer un mot-clé',

	// I
	'icone_creation_groupe_mots' => 'Créer un nouveau groupe de mots',
	'icone_creation_mots_cles' => 'Créer un nouveau mot-clé',
	'icone_modif_groupe_mots' => 'Modifier ce groupe de mots',
	'icone_modifier_mot' => 'Modifier ce mot-clé',
	'icone_mots_cles' => 'Mots-clés',
	'icone_supprimer_groupe_mots' => 'Supprimer ce groupe',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots',
	'icone_voir_tous_mots_cles' => 'Voir tous les mots-clés',
	'info_1_groupe_mots' => '1 groupe de mots',
	'info_articles_lies_mot' => 'Les articles liés à ce mot-clé',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots',
	'info_aucun_mot_cle' => 'Aucun mot-clé',
	'info_changer_nom_groupe' => 'Changer le nom de ce groupe :',
	'info_creation_mots_cles' => 'Créez et configurez ici les mots-clés du site',
	'info_dans_groupe' => 'Dans le groupe :',
	'info_delet_mots_cles' => 'Vous avez demandé à supprimer le mot-clé <b>@titre_mot@</b> (@type_mot@). Ce mot-clé étant lié à <b>@texte_lie@</b> vous devez confirmer cette décision :',
	'info_groupe_important' => 'Groupe important',
	'info_modifier_mot' => 'Modifier le mot-clé :',
	'info_mots_cles' => 'Les mots-clés',
	'info_mots_cles_association' => 'Les mots-clés de ce groupe peuvent être associés :',
	'info_nb_groupe_mots' => '@nb@ groupes de mots',
	'info_oui_suppression_mot_cle' => 'je veux supprimer définitivement ce mot-clé.',
	'info_question_mots_cles' => 'Souhaitez-vous utiliser les mots-clés sur votre site ?',
	'info_qui_attribue_mot_cle' => 'Les mots de ce groupe peuvent être attribués par :',
	'info_remplacer_mot' => 'Remplacer "@titre@"',
	'info_retirer_mot' => 'Retirer ce mot',
	'info_retirer_mots' => 'Retirer tous les mots',
	'info_rubriques_liees_mot' => 'Les rubriques liées à ce mot-clé',
	'info_selection_un_seul_mot_cle' => 'On ne peut sélectionner qu\'<b>un seul</b> mot-clé à la fois dans ce groupe.',
	'info_supprimer_mot' => 'supprimer ce mot',
	'info_titre_mot_cle' => 'Nom ou titre du mot-clé',
	'info_un_mot' => 'Un seul mot à la fois',
	'item_ajout_mots_cles' => 'Autoriser l\'ajout de mots-clés aux forums',
	'item_non_ajout_mots_cles' => 'Interdire l\'utilisation des mots-clés dans les forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ne pas utiliser la configuration avancée des groupes de mots-clés',
	'item_non_utiliser_mots_cles' => 'Ne pas utiliser les mots-clés',
	'item_utiliser_config_groupe_mots_cles' => 'Utiliser la configuration avancée des groupes de mots-clés',
	'item_utiliser_mots_cles' => 'Utiliser les mots-clés',

	// L
	'lien_ajouter_mot' => 'Ajouter ce mot-clé',
	'logo_groupe' => 'LOGO DE CE GROUPE',
	'logo_mot_cle' => 'LOGO DU MOT-CLÉ',

	// T
	'texte_config_groupe_mots_cles' => 'Souhaitez-vous activer la configuration avancée des mots-clés, en indiquant par exemple qu\'on peut sélectionner un mot unique par groupe, qu\'un groupe est important… ?',
	'texte_mots_cles' => 'Les mots-clés permettent de créer des liens thématiques entre vos articles
		indépendamment de leur placement dans des rubriques. Vous pouvez ainsi
		enrichir la navigation de votre site, voire utiliser ces propriétés
		pour personnaliser la présentation des articles dans vos squelettes.',
	'texte_mots_cles_dans_forum' => 'Souhaitez-vous permettre l\'utilisation de mots-clés sélectionnables par les visiteurs dans les forums du site public ? (Attention : cette option est relativement complexe à utiliser correctement.)',
	'texte_nouveau_mot' => 'Nouveau mot',
	'titre_config_groupe_mots_cles' => 'Configuration des groupes de mots-clés',
	'titre_gauche_mots_edit' => 'MOT NUMÉRO :',
	'titre_groupe_mots' => 'Groupe de mots-clés',
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :',
	'titre_groupes_mots' => 'Groupes de mots-clés',
	'titre_mots_cles_dans_forum' => 'Mots-clés dans les forums du site public',
	'titre_mots_tous' => 'Les mots-clés',
	'titre_nouveau_groupe' => 'Nouveau groupe',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :',
	'titre_page_mots_tous' => 'Mots-clés'
);

?>

==> spip_3.0.11.orig.tar.xz: spip-3.0.11.orig/plugins-dist/mots/lang/mots_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/mots/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Groupe important :</b> il est fortement conseillé de sélectionner un mot-clé dans ce groupe.',
	'avis_doublon_mot_cle' => 'Un mot existe déjà avec ce titre. Êtes vous sûr de vouloir créer le même ?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'les administrateurs du site',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'les rédacteurs',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'les visiteurs du site public lorsqu\'ils postent un message dans un forum.',

	// C
	'creer_et_associer_un_mot' => 'Créer et associer un mot-clé',

	// I
	'icone_creation_groupe_mots' => 'Créer un nouveau groupe de mots',
	'icone_creation_mots_cles' => 'Créer un nouveau mot-clé',
	'icone_modif_groupe_mots' => 'Modifier ce groupe de mots',
	'icone_modifier_mot' => 'Modifier ce mot-clé',
	'icone_mots_cles' => 'Mots-clés',
	'icone_supprimer_groupe_mots' => 'Supprimer ce groupe',
	'icone_voir_groupe_mots' => 'Voir ce groupe de mots',
	'icone_voir_tous_mots_cles' => 'Voir tous les mots-clés',
	'info_1_groupe_mots' => '1 groupe de mots',
	'info_articles_lies_mot' => 'Les articles liés à ce mot-clé',
	'info_aucun_groupe_mots' => 'Aucun groupe de mots',
	'info_aucun_mot_cle' => 'Aucun mot-clé',
	'info_changer_nom_groupe' => 'Changer le nom de ce groupe :',
	'info_creation_mots_cles' => 'Créez et configurez ici les mots-clés du site',
	'info_dans_groupe' => 'Dans le groupe :',
	'info_delet_mots_cles' => 'Vous avez demandé à supprimer le mot-clé <b>@titre_mot@</b> (@type_mot@). Ce mot-clé étant lié à <b>@texte_lie@</b> vous devez confirmer cette décision :',
	'info_groupe_important' => 'Groupe important',
	'info_modifier_mot' => 'Modifier le mot-clé :',
	'info_mots_cles' => 'Les mots-clés',
	'info_mots_cles_association' => 'Les mots-clés de ce groupe peuvent être associés :',
	'info_nb_groupe_mots' => '@nb@ groupes de mots',
	'info_oui_suppression_mot_cle' => 'je veux supprimer définitivement ce mot-clé.',
	'info_question_mots_cles' => 'Souhaitez-vous utiliser les mots-clés sur votre site ?',
	'info_qui_attribue_mot_cle' => 'Les mots de ce groupe peuvent être attribués par :',
	'info_remplacer_mot' => 'Remplacer "@titre@"',
	'info_retirer_mot' => 'Retirer ce mot',
	'info_retirer_mots' => 'Retirer tous les mots',
	'info_rubriques_liees_mot' => 'Les rubriques liées à ce mot-clé',
	'info_selection_un_seul_mot_cle' => 'On ne peut sélectionner qu\'<b>un seul</b> mot-clé à la fois dans ce groupe.',
	'info_supprimer_mot' => 'supprimer ce mot',
	'info_titre_mot_cle' => 'Nom ou titre du mot-clé',
	'info_un_mot' => 'Un seul mot à la fois',
	'item_ajout_mots_cles' => 'Autoriser l\'ajout de mots-clés aux forums',
	'item_non_ajout_mots_cles' => 'Interdire l\'utilisation des mots-clés dans les forums',
	'item_non_utiliser_config_groupe_mots_cles' => 'Ne pas utiliser la configuration avancée des groupes de mots-clés',
	'item_non_utiliser_mots_cles' => 'Ne pas utiliser les mots-clés',
	'item_utiliser_config_groupe_mots_cles' => 'Utiliser la configuration avancée des groupes de mots-clés',
	'item_utiliser_mots_cles' => 'Utiliser les mots-clés',

	// L
	'lien_ajouter_mot' => 'Ajouter ce mot-clé',
	'logo_groupe' => 'LOGO DE CE GROUPE',
	'logo_mot_cle' => 'LOGO DU MOT-CLÉ',

	// T
	'texte_config_groupe_mots_cles' => 'Souhaitez-vous activer la configuration avancée des mots-clés, en indiquant par exemple qu\'on peut sélectionner un mot unique par groupe, qu\'un groupe est important… ?',
	'texte_mots_cles' => 'Les mots-clés permettent de créer des liens thématiques entre vos articles
		indépendamment de leur placement dans des rubriques. Vous pouvez ainsi
		enrichir la navigation de votre site, voire utiliser ces propriétés
		pour personnaliser la présentation des articles dans vos squelettes.',
	'texte_mots_cles_dans_forum' => 'Souhaitez-vous permettre l\'utilisation de mots-clés sélectionnables par les visiteurs dans les forums du site public ? (Attention : cette option est relativement complexe à utiliser correctement.)',
	'texte_nouveau_mot' => 'Nouveau mot',
	'titre_config_groupe_mots_cles' => 'Configuration des groupes de mots-clés',
	'titre_gauche_mots_edit' => 'MOT NUMÉRO :',
	'titre_groupe_mots' => 'Groupe de mots-clés',
	'titre_groupe_mots_numero' => 'GROUPE DE MOTS NUMÉRO :',
	'titre_groupes_mots' => 'Groupes de mots-clés',
	'titre_mots_cles_dans_forum' => 'Mots-clés dans les forums du site public',
	'titre_mots_tous' => 'Les mots-clés',
	'titre_nouveau_groupe' => 'Nouveau groupe',
	'titre_objets_lies_mot' => 'Liés à ce mot-clé :',
	'titre_page_mots_tous' => 'Mots-clés'
);

?>
